@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2021 IRT Saint Exupéry, https://www.irt-saintexupery.com
 #
 # This program is free software; you can redistribute it and/or
@@ -13,9 +12,8 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+"""|g| Design of Experiments package.
 
+Contains wrappers to DOE algorithm libraries.
 """
-|g| Design of Experiments package
-Contains wrappers to DOE algorithm libraries
-
-"""
+from __future__ import annotations
