@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2021 IRT Saint Exupéry, https://www.irt-saintexupery.com
 #
 # This program is free software; you can redistribute it and/or
@@ -13,62 +12,44 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
 """Provide base test class stub for testing bilevel also for |g| plugins."""
-from __future__ import division, unicode_literals
+from __future__ import annotations
 
-import unittest
 from copy import deepcopy
+from typing import Callable
 
 from gemseo.core.mdo_scenario import MDOScenario
-from gemseo.problems.sobieski.wrappers import (
-    SobieskiAerodynamics,
-    SobieskiMission,
-    SobieskiProblem,
-    SobieskiPropulsion,
-    SobieskiStructure,
-)
+from gemseo.problems.sobieski.disciplines import SobieskiAerodynamics
+from gemseo.problems.sobieski.disciplines import SobieskiMission
+from gemseo.problems.sobieski.disciplines import SobieskiProblem
+from gemseo.problems.sobieski.disciplines import SobieskiPropulsion
+from gemseo.problems.sobieski.disciplines import SobieskiStructure
 
 
-def build_system_scenario(disciplines, **options):
+def create_sobieski_bilevel_scenario() -> Callable[[dict[str, float]], MDOScenario]:
+    """Create a function to generate a Sobieski BiLevel Scenario.
+
+    Returns:
+        A function which generates a Sobieski BiLevel Scenario with specific options.
     """
 
-    :param disciplines:
+    def func(**options):
+        """Create a Sobieski BiLevel scenario.
 
-    """
-    # Maximize range (Breguet)
-    ds = SobieskiProblem().read_design_space()
-    # Add a coupling to DV but bielevel filters it
-    sc_system = MDOScenario(
-        disciplines,
-        formulation="BiLevel",
-        objective_name="y_4",
-        design_space=ds.filter(["x_shared", "y_14"]),
-        maximize_objective=True,
-        **options
-    )
-    assert sc_system.formulation.opt_problem.design_space.variables_names == [
-        "x_shared"
-    ]
-    sc_system.set_differentiation_method("finite_differences", step=1e-6)
-    return sc_system
+        Args:
+             **options: The options of the system scenario.
 
+        Returns:
+            A Sobieski BiLevel Scenario.
+        """
+        propulsion = SobieskiPropulsion()
+        aerodynamics = SobieskiAerodynamics()
+        struct = SobieskiStructure()
+        mission = SobieskiMission()
 
-class TestBilevelFormulationBase(unittest.TestCase):
-    """Helper class for testing bilevel formulations."""
-
-    @classmethod
-    def setUpClass(cls):
-        cls.propulsion = SobieskiPropulsion()
-        cls.aerodynamics = SobieskiAerodynamics()
-        cls.struct = SobieskiStructure()
-        cls.mission = SobieskiMission()
-
-    def build_scenarios(self):
-        """"""
-        ds = SobieskiProblem().read_design_space()
+        ds = SobieskiProblem().design_space
         sc_prop = MDOScenario(
-            disciplines=[self.propulsion],
+            disciplines=[propulsion],
             formulation="DisciplinaryOpt",
             objective_name="y_34",
             design_space=deepcopy(ds).filter("x_3"),
@@ -77,7 +58,7 @@ class TestBilevelFormulationBase(unittest.TestCase):
 
         # Maximize L/D
         sc_aero = MDOScenario(
-            disciplines=[self.aerodynamics],
+            disciplines=[aerodynamics],
             formulation="DisciplinaryOpt",
             objective_name="y_24",
             design_space=deepcopy(ds).filter("x_2"),
@@ -88,7 +69,7 @@ class TestBilevelFormulationBase(unittest.TestCase):
         # Maximize log(aircraft total weight / (aircraft total weight - fuel
         # weight))
         sc_str = MDOScenario(
-            disciplines=[self.struct],
+            disciplines=[struct],
             formulation="DisciplinaryOpt",
             objective_name="y_11",
             design_space=deepcopy(ds).filter("x_1"),
@@ -96,13 +77,21 @@ class TestBilevelFormulationBase(unittest.TestCase):
             maximize_objective=True,
         )
 
-        return sc_str, sc_aero, sc_prop
-
-    def build_bilevel(self, **options):
-        """"""
-        sub_scenarios = self.build_scenarios()
-        sub_disciplines = list(sub_scenarios) + [self.mission]
+        sub_scenarios = [sc_str, sc_aero, sc_prop]
+        sub_disciplines = sub_scenarios + [mission]
         for sc in sub_scenarios:
             sc.default_inputs = {"max_iter": 5, "algo": "SLSQP"}
-        system_scenario = build_system_scenario(sub_disciplines, **options)
-        return system_scenario
+
+        ds = SobieskiProblem().design_space
+        sc_system = MDOScenario(
+            sub_disciplines,
+            formulation="BiLevel",
+            objective_name="y_4",
+            design_space=ds.filter(["x_shared", "y_14"]),
+            maximize_objective=True,
+            **options,
+        )
+        sc_system.set_differentiation_method("finite_differences", step=1e-6)
+        return sc_system
+
+    return func
