@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2021 IRT Saint Exupéry, https://www.irt-saintexupery.com
 #
 # This program is free software; you can redistribute it and/or
@@ -13,25 +12,27 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
 # Contributors:
 #    INITIAL AUTHORS - API and implementation and/or documentation
 #        :author: Francois Gallard
 #    OTHER AUTHORS   - MACROSCOPIC CHANGES
-"""
-A Gauss Seidel algorithm for solving MDAs
-*****************************************
-"""
-from __future__ import division, unicode_literals
+"""A Gauss Seidel algorithm for solving MDAs."""
+from __future__ import annotations
+
+from typing import Any
+from typing import Mapping
+from typing import Sequence
 
 from gemseo.core.chain import MDOChain
+from gemseo.core.coupling_structure import MDOCouplingStructure
 from gemseo.core.discipline import MDODiscipline
 from gemseo.mda.mda import MDA
 
 
 class MDAGaussSeidel(MDA):
-    """Perform a MDA analysis using a Gauss-Seidel algorithm, an iterative technique to
-    solve the linear system:
+    """An MDA analysis based on the Gauss-Seidel algorithm.
+
+    This algorithm is an iterative technique to solve the linear system:
 
     .. math::
 
@@ -48,51 +49,37 @@ class MDAGaussSeidel(MDA):
        x_{k+1} = L_*^{-1}(b-Ux_k)
     """
 
+    _ATTR_TO_SERIALIZE = MDA._ATTR_TO_SERIALIZE + (
+        "strong_couplings",
+        "over_relax_factor",
+        "normed_residual",
+    )
+
     def __init__(
         self,
-        disciplines,
-        name=None,
-        max_mda_iter=10,
-        grammar_type=MDODiscipline.JSON_GRAMMAR_TYPE,
-        tolerance=1e-6,
-        linear_solver_tolerance=1e-12,
-        warm_start=False,
-        use_lu_fact=False,
-        over_relax_factor=1.0,
-    ):
-        """Constructor.
-
-        :param disciplines: the disciplines list
-        :type disciplines: list(MDODiscipline)
-        :param max_mda_iter: maximum number of iterations
-        :type max_mda_iter: int
-        :param name: the name of the chain
-        :type name: str
-        :param grammar_type: the type of grammar to use for IO declaration
-            either JSON_GRAMMAR_TYPE or SIMPLE_GRAMMAR_TYPE
-        :type grammar_type: str
-        :param tolerance: tolerance of the iterative direct coupling solver,
-            norm of the current residuals divided by initial residuals norm
-            shall be lower than the tolerance to stop iterating
-        :type tolerance: float
-        :param linear_solver_tolerance: Tolerance of the linear solver
-            in the adjoint equation
-        :type linear_solver_tolerance: float
-        :param warm_start: if True, the second iteration and ongoing
-            start from the previous coupling solution
-        :type warm_start: bool
-        :param use_lu_fact: if True, when using adjoint/forward
-            differenciation, store a LU factorization of the matrix
-            to solve faster multiple RHS problem
-        :type use_lu_fact: bool
-        :param over_relax_factor: relaxation coefficient, used to make the
-            method more robust, if 0<over_relax_factor<1
-            or faster if 1<over_relax_factor<=2.
-            If over_relax_factor =1., it is deactivated
-        :type over_relax_factor: float
+        disciplines: Sequence[MDODiscipline],
+        name: str | None = None,
+        max_mda_iter: int = 10,
+        grammar_type: str = MDODiscipline.JSON_GRAMMAR_TYPE,
+        tolerance: float = 1e-6,
+        linear_solver_tolerance: float = 1e-12,
+        warm_start: bool = False,
+        use_lu_fact: bool = False,
+        over_relax_factor: float = 1.0,
+        coupling_structure: MDOCouplingStructure | None = None,
+        log_convergence: bool = False,
+        linear_solver: str = "DEFAULT",
+        linear_solver_options: Mapping[str, Any] = None,
+    ) -> None:
+        """
+        Args:
+            over_relax_factor: The relaxation coefficient,
+                used to make the method more robust,
+                if ``0<over_relax_factor<1`` or faster if ``1<over_relax_factor<=2``.
+                If ``over_relax_factor =1.``, it is deactivated.
         """
         self.chain = MDOChain(disciplines, grammar_type=grammar_type)
-        super(MDAGaussSeidel, self).__init__(
+        super().__init__(
             disciplines,
             max_mda_iter=max_mda_iter,
             name=name,
@@ -101,35 +88,32 @@ class MDAGaussSeidel(MDA):
             linear_solver_tolerance=linear_solver_tolerance,
             warm_start=warm_start,
             use_lu_fact=use_lu_fact,
+            coupling_structure=coupling_structure,
+            log_convergence=log_convergence,
+            linear_solver=linear_solver,
+            linear_solver_options=linear_solver_options,
         )
         assert over_relax_factor > 0.0
         assert over_relax_factor <= 2.0
         self.over_relax_factor = over_relax_factor
-        self._initialize_grammars()
         self._set_default_inputs()
         self._compute_input_couplings()
 
     def _initialize_grammars(self):
-        """Defines all inputs and outputs of the chain."""
-        # self.chain.initialize_grammars()
-        self.input_grammar.update_from(self.chain.input_grammar)
-        self.output_grammar.update_from(self.chain.output_grammar)
+        self.input_grammar.update(self.chain.input_grammar)
+        self.output_grammar.update(self.chain.output_grammar)
 
     def _run(self):
-        """Runs the disciplines in a sequential way until the difference between outputs
-        is under tolerance.
-
-        :returns: the local data
-        """
+        # Run the disciplines in a sequential way
+        # until the difference between outputs is under tolerance.
         if self.warm_start:
             self._couplings_warm_start()
         current_couplings = 0.0
 
         relax = self.over_relax_factor
         use_relax = relax != 1.0
-        # store initial residual
-        current_iter = 0
-        while not self._termination(current_iter) or current_iter == 0:
+
+        while not self._stop_criterion_is_reached or self._current_iter == 0:
             for discipline in self.disciplines:
                 discipline.execute(self.local_data)
                 outs = discipline.get_output_data()
@@ -152,10 +136,10 @@ class MDAGaussSeidel(MDA):
 
             new_couplings = self._current_strong_couplings()
             self._compute_residual(
-                current_couplings, new_couplings, current_iter, first=current_iter == 0
+                current_couplings,
+                new_couplings,
+                log_normed_residual=self.log_convergence,
             )
-            # store current residuals
-            current_iter += 1
             current_couplings = new_couplings
 
         for discipline in self.disciplines:  # Update all outputs without relax
