@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2021 IRT Saint Exupéry, https://www.irt-saintexupery.com
 #
 # This program is free software; you can redistribute it and/or
@@ -13,7 +12,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
 # Contributors:
 #    INITIAL AUTHORS - initial API and implementation and/or initial
 #                         documentation
@@ -35,18 +33,26 @@ which inherits from the :class:`.MLUnsupervisedAlgo` class,
 and through the :class:`.MLPredictiveClusteringAlgo` class
 which inherits from :class:`.MLClusteringAlgo`.
 """
-from __future__ import division, unicode_literals
+from __future__ import annotations
 
-from typing import Dict, Iterable, List, NoReturn, Optional, Union
+from typing import Iterable
+from typing import Mapping
+from typing import NoReturn
+from typing import Sequence
+from typing import Union
 
-from numpy import atleast_2d, ndarray, unique, zeros
+from numpy import atleast_2d
+from numpy import ndarray
+from numpy import unique
+from numpy import zeros
 
 from gemseo.core.dataset import Dataset
-from gemseo.mlearning.core.ml_algo import DataType, MLAlgoParameterType
+from gemseo.mlearning.core.ml_algo import DataType
+from gemseo.mlearning.core.ml_algo import MLAlgoParameterType
 from gemseo.mlearning.core.ml_algo import SavedObjectType as MLAlgoSavedObjectType
 from gemseo.mlearning.core.ml_algo import TransformerType
 from gemseo.mlearning.core.unsupervised import MLUnsupervisedAlgo
-from gemseo.utils.data_conversion import DataConversion
+from gemseo.utils.data_conversion import concatenate_dict_of_arrays_to_array
 
 SavedObjectType = Union[MLAlgoSavedObjectType, ndarray, int]
 
@@ -56,36 +62,39 @@ class MLClusteringAlgo(MLUnsupervisedAlgo):
 
     The inheriting classes shall overload the
     :meth:`!MLUnsupervisedAlgo._fit` method.
-
-    Attributes:
-        labels (List(int)): The indices of the clusters for the different samples.
-        n_clusters (int): The number of clusters.
     """
 
+    labels: list[int]
+    """The indices of the clusters for the different samples."""
+
+    n_clusters: int
+    """The number of clusters."""
+
     def __init__(
         self,
-        data,  # type:Dataset
-        transformer=None,  # type: Optional[TransformerType]
-        var_names=None,  # type: Optional[Iterable[str]]
-        **parameters  # type:MLAlgoParameterType
-    ):  # type: (...) -> None
-        super(MLClusteringAlgo, self).__init__(
+        data: Dataset,
+        transformer: Mapping[str, TransformerType] | None = None,
+        var_names: Iterable[str] | None = None,
+        **parameters: MLAlgoParameterType,
+    ) -> None:
+        super().__init__(
             data, transformer=transformer, var_names=var_names, **parameters
         )
         self.labels = None
         self.n_clusters = None
 
-    def learn(
+    def _learn(
         self,
-        samples=None,  # type: Optional[List[int]]
-    ):  # type: (...) -> None
-        super(MLClusteringAlgo, self).learn(samples=samples)
+        indices: Sequence[int] | None,
+        fit_transformers: bool,
+    ) -> None:
+        super()._learn(indices, fit_transformers=fit_transformers)
         if self.labels is None:
             raise ValueError("self._fit() shall assign labels.")
         self.n_clusters = unique(self.labels).shape[0]
 
-    def _get_objects_to_save(self):  # type: (...) -> Dict[str,SavedObjectType]
-        objects = super(MLClusteringAlgo, self)._get_objects_to_save()
+    def _get_objects_to_save(self) -> dict[str, SavedObjectType]:
+        objects = super()._get_objects_to_save()
         objects["labels"] = self.labels
         objects["n_clusters"] = self.n_clusters
         return objects
@@ -102,8 +111,8 @@ class MLPredictiveClusteringAlgo(MLClusteringAlgo):
 
     def predict(
         self,
-        data,  # type: DataType
-    ):  # type: (...) -> Union[int,ndarray]
+        data: DataType,
+    ) -> int | ndarray:
         """Predict the clusters from the input data.
 
         The user can specify these input data either as a NumPy array,
@@ -128,7 +137,7 @@ class MLPredictiveClusteringAlgo(MLClusteringAlgo):
         """
         as_dict = isinstance(data, dict)
         if as_dict:
-            data = DataConversion.dict_to_array(data, self.var_names)
+            data = concatenate_dict_of_arrays_to_array(data, self.var_names)
         single_sample = len(data.shape) == 1
         data = atleast_2d(data)
         parameters = self.learning_set.DEFAULT_GROUP
@@ -141,8 +150,8 @@ class MLPredictiveClusteringAlgo(MLClusteringAlgo):
 
     def _predict(
         self,
-        data,  # type: ndarray
-    ):  # type: (...) -> NoReturn
+        data: ndarray,
+    ) -> NoReturn:
         """Predict the clusters from input data.
 
         Args:
@@ -155,9 +164,9 @@ class MLPredictiveClusteringAlgo(MLClusteringAlgo):
 
     def predict_proba(
         self,
-        data,  # type: DataType
-        hard=True,  # type: bool
-    ):  # type: (...)-> ndarray
+        data: DataType,
+        hard: bool = True,
+    ) -> ndarray:
         """Predict the probability of belonging to each cluster from input data.
 
         The user can specified these input data either as a numpy array,
@@ -183,7 +192,7 @@ class MLPredictiveClusteringAlgo(MLClusteringAlgo):
         """
         as_dict = isinstance(data, dict)
         if as_dict:
-            data = DataConversion.dict_to_array(data, self.var_names)
+            data = concatenate_dict_of_arrays_to_array(data, self.var_names)
         single_sample = len(data.shape) == 1
         data = atleast_2d(data)
         probas = self._predict_proba(atleast_2d(data), hard)
@@ -193,9 +202,9 @@ class MLPredictiveClusteringAlgo(MLClusteringAlgo):
 
     def _predict_proba(
         self,
-        data,  # type: ndarray
-        hard=True,  # type: bool
-    ):  # type: (...)-> ndarray
+        data: ndarray,
+        hard: bool = True,
+    ) -> ndarray:
         """Predict the probability of belonging to each cluster.
 
         Args:
@@ -214,8 +223,8 @@ class MLPredictiveClusteringAlgo(MLClusteringAlgo):
 
     def _predict_proba_hard(
         self,
-        data,  # type: ndarray
-    ):  # type: (...)-> ndarray
+        data: ndarray,
+    ) -> ndarray:
         """Return 1 if the data belongs to a cluster, 0 otherwise.
 
         Args:
@@ -233,8 +242,8 @@ class MLPredictiveClusteringAlgo(MLClusteringAlgo):
 
     def _predict_proba_soft(
         self,
-        data,  # type: ndarray
-    ):  # type: (...)-> NoReturn
+        data: ndarray,
+    ) -> NoReturn:
         """Predict the probability of belonging to each cluster.
 
         Args:
