@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2021 IRT Saint Exupéry, https://www.irt-saintexupery.com
 #
 # This program is free software; you can redistribute it and/or
@@ -13,7 +12,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
 # Contributors:
 #    INITIAL AUTHORS - initial API and implementation and/or initial
 #                           documentation
@@ -22,10 +20,10 @@
 """A factory to create clustering models.
 
 This module contains a factory to instantiate a :class:`.MLClusteringAlgo` from its
-class name. It also provides a list of available clustering models and allows to test if
+class name. It also provides a list of available clustering models and allows testing if
 a clustering model type is available.
 """
-from __future__ import division, unicode_literals
+from __future__ import annotations
 
 import logging
 
@@ -39,14 +37,13 @@ LOGGER = logging.getLogger(__name__)
 class ClusteringModelFactory(MLAlgoFactory):
     """This factory instantiates a :class:`.MLClusteringAlgo` from its class name.
 
-    The class can be either internal to |g| or external. In this second case, it can be
-    either implemented in a module referenced in the "GEMSEO_PATH" or in a module The
-    class can be either internal to |g| or external. In the second case, it can be
-    either implemented in a module referenced in the GEMSEO_PATH environment variable or
-    in a module starting with "gemseo_" and referenced in the PYTHONPATH environment
-    variable.
+    The class can be either internal or external. In this second case, it can be either
+    implemented in a module referenced in the "GEMSEO_PATH" or in a module The class can
+    be either internal or external. In the second case, it can be either implemented in
+    a module referenced in the GEMSEO_PATH environment variable or in a module starting
+    with "gemseo_" and referenced in the PYTHONPATH environment variable.
     """
 
-    def __init__(self):  # type: (...) -> None
-        super(ClusteringModelFactory, self).__init__()
+    def __init__(self) -> None:
+        super().__init__()
         self.factory = Factory(MLClusteringAlgo, ("gemseo.mlearning.cluster",))
