@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2021 IRT Saint Exupéry, https://www.irt-saintexupery.com
 #
 # This program is free software; you can redistribute it and/or
@@ -13,21 +12,20 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
 # Contributors:
 #    INITIAL AUTHORS - initial API and implementation and/or initial
 #                         documentation
 #        :author: Syver Doving Agdestein
 #    OTHER AUTHORS   - MACROSCOPIC CHANGES
-r"""The polynomial model for regression.
+r"""Polynomial regression model.
 
-Polynomial regression class is a particular case of the linear regression,
+Polynomial regression is a particular case of the linear regression,
 where the input data is transformed before the regression is applied.
-This transform consists of creating a matrix of monomials (Vandermonde)
+This transform consists of creating a matrix of monomials
 by raising the input data to different powers up to a certain degree :math:`D`.
 In the case where there is only one input variable,
 the input data :math:`(x_i)_{i=1, \dots, n}\in\mathbb{R}^n` is transformed
-into the Vandermonde matrix
+into the Vandermonde matrix:
 
 .. math::
 
@@ -39,13 +37,13 @@ into the Vandermonde matrix
     \end{pmatrix}
     = (x_i^d)_{i=1, \dots, n;\ d=1, \dots, D}.
 
-The output is expressed as a weighted sum of monomials:
+The output variable is expressed as a weighted sum of monomials:
 
 .. math::
 
      y = w_0 + w_1 x^1 + w_2 x^2 + ... + w_D x^D,
 
-where the coefficients :math:`(w_1, w_2, ..., w_d)` and the intercept :math:`w_0`
+where the coefficients :math:`w_1, w_2, ..., w_d` and the intercept :math:`w_0`
 are estimated by least square regression.
 
 In the case of a multidimensional input,
@@ -58,66 +56,68 @@ the different terms are
 :math:`x`, :math:`y`, :math:`z`, :math:`x^2`, :math:`xy`, :math:`xz`,
 :math:`y^2`, :math:`yz`, :math:`z^2`, :math:`x^3`, :math:`x^2y` etc.
 More generally,
-for m input variables,
+for :math:`m` input variables,
 the total number of monomials of degree :math:`1 \leq d \leq D` is given
 by :math:`P = \binom{m+D}{m} = \frac{(m+D)!}{m!D!}`.
 In the case of 3 input variables given above,
 the total number of monomial combinations of degree lesser than or equal to three
 is thus :math:`P = \binom{6}{3} = 20`.
-The linear regression has to identify the coefficients :math:`(w_1, \dots, w_P)`,
+The linear regression has to identify the coefficients :math:`w_1, \dots, w_P`,
 in addition to the intercept :math:`w_0`.
 
-This concept is implemented through the :class:`.PolynomialRegression` class
-which inherits from the :class:`.MLRegressionAlgo` class.
-
 Dependence
 ----------
-The polynomial regression model relies on the LinearRegression class
-of the `LinearRegression <https://scikit-learn.org/stable/modules/
+The polynomial regression model relies
+on the `LinearRegression <https://scikit-learn.org/stable/modules/
 linear_model.html>`_ and  `PolynomialFeatures <https://scikit-learn.org/stable/
 modules/generated/sklearn.preprocessing.PolynomialFeatures.html>`_ classes of
 the `scikit-learn library <https://scikit-learn.org/stable/modules/
 linear_model.html>`_.
 """
-from __future__ import division, unicode_literals
+from __future__ import annotations
 
 import logging
 import pickle
-from os.path import join
-from typing import Iterable, Optional, Union
+from pathlib import Path
+from typing import ClassVar
+from typing import Iterable
+from typing import Mapping
 
-from numpy import concatenate, ndarray, where, zeros
+from numpy import concatenate
+from numpy import ndarray
+from numpy import where
+from numpy import zeros
 from sklearn.preprocessing import PolynomialFeatures
 
 from gemseo.core.dataset import Dataset
-from gemseo.mlearning.core.ml_algo import DataType, TransformerType
-from gemseo.mlearning.regression.linreg import LinearRegression
+from gemseo.mlearning.core.ml_algo import DataType
+from gemseo.mlearning.core.ml_algo import TransformerType
+from gemseo.mlearning.regression.linreg import LinearRegressor
 
 LOGGER = logging.getLogger(__name__)
 
 
-class PolynomialRegression(LinearRegression):
-    """Polynomial regression."""
+class PolynomialRegressor(LinearRegressor):
+    """Polynomial regression model."""
 
-    LIBRARY = "scikit-learn"
-    ABBR = "PolyReg"
+    SHORT_ALGO_NAME: ClassVar[str] = "PolyReg"
 
     def __init__(
         self,
-        data,  # type: Dataset
-        degree,  # type: int
-        transformer=None,  # type: Optional[TransformerType]
-        input_names=None,  # type: Optional[Iterable[str]]
-        output_names=None,  # type: Optional[Iterable[str]]
-        fit_intercept=True,  # type: bool
-        penalty_level=0.0,  # type: float
-        l2_penalty_ratio=1.0,  # type: float
-        **parameters  # type: Optional[Union[float,int,str,bool]]
-    ):  # type: (...) -> None
+        data: Dataset,
+        degree: int,
+        transformer: Mapping[str, TransformerType] | None = None,
+        input_names: Iterable[str] | None = None,
+        output_names: Iterable[str] | None = None,
+        fit_intercept: bool = True,
+        penalty_level: float = 0.0,
+        l2_penalty_ratio: float = 1.0,
+        **parameters: float | int | str | bool | None,
+    ) -> None:
         """
         Args:
             degree: The polynomial degree.
-            fit_intercept: If True, fit intercept.
+            fit_intercept: Whether to fit the intercept.
             penalty_level: The penalty level greater or equal to 0.
                 If 0, there is no penalty.
             l2_penalty_ratio: The penalty ratio
@@ -129,7 +129,7 @@ class PolynomialRegression(LinearRegression):
         Raises:
             ValueError: If the degree is lower than one.
         """
-        super(PolynomialRegression, self).__init__(
+        super().__init__(
             data,
             degree=degree,
             transformer=transformer,
@@ -138,7 +138,7 @@ class PolynomialRegression(LinearRegression):
             fit_intercept=fit_intercept,
             penalty_level=penalty_level,
             l2_penalty_ratio=l2_penalty_ratio,
-            **parameters
+            **parameters,
         )
         self._poly = PolynomialFeatures(degree=degree, include_bias=False)
         self.parameters["degree"] = degree
@@ -147,23 +147,23 @@ class PolynomialRegression(LinearRegression):
 
     def _fit(
         self,
-        input_data,  # type: ndarray
-        output_data,  # type: ndarray
-    ):  # type: (...) -> None
+        input_data: ndarray,
+        output_data: ndarray,
+    ) -> None:
         input_data = self._poly.fit_transform(input_data)
-        super(PolynomialRegression, self)._fit(input_data, output_data)
+        super()._fit(input_data, output_data)
 
     def _predict(
         self,
-        input_data,  # type: ndarray
-    ):  # type: (...) -> ndarray
+        input_data: ndarray,
+    ) -> ndarray:
         input_data = self._poly.transform(input_data)
-        return super(PolynomialRegression, self)._predict(input_data)
+        return super()._predict(input_data)
 
     def _predict_jacobian(
         self,
-        input_data,  # type: ndarray
-    ):  # type: (...) -> ndarray
+        input_data: ndarray,
+    ) -> ndarray:
         # Dimensions:
         # powers:        (           ,            ,  n_powers ,  n_inputs )
         # coefs:         (           ,  n_outputs ,  n_powers ,           )
@@ -228,8 +228,8 @@ class PolynomialRegression(LinearRegression):
 
     def get_coefficients(
         self,
-        as_dict=False,  # type:bool
-    ):  # type: (...) -> DataType
+        as_dict: bool = False,
+    ) -> DataType:
         """Return the regression coefficients of the linear model.
 
         Args:
@@ -254,19 +254,18 @@ class PolynomialRegression(LinearRegression):
 
     def _save_algo(
         self,
-        directory,  # type: str
-    ):  # type: (...) -> None
-        super(PolynomialRegression, self)._save_algo(directory)
-        filename = join(directory, "poly.pkl")
-        with open(filename, "wb") as handle:
+        directory: Path,
+    ) -> None:
+        super()._save_algo(directory)
+        with (directory / "poly.pkl").open("wb") as handle:
             pickle.dump(self._poly, handle)
 
     def load_algo(
         self,
-        directory,  # type: str
-    ):  # type: (...) -> None
-        super(PolynomialRegression, self).load_algo(directory)
-        filename = join(directory, "poly.pkl")
-        with open(filename, "rb") as handle:
+        directory: str | Path,
+    ) -> None:
+        directory = Path(directory)
+        super().load_algo(directory)
+        with (directory / "poly.pkl").open("rb") as handle:
             poly = pickle.load(handle)
         self._poly = poly
