@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2021 IRT Saint Exupéry, https://www.irt-saintexupery.com
 #
 # This program is free software; you can redistribute it and/or
@@ -13,7 +12,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
 # Contributors:
 #    INITIAL AUTHORS - initial API and implementation and/or initial
 #                         documentation
@@ -27,13 +25,14 @@ The :class:`.DimensionReduction` class implements the concept of dimension reduc
 
    :mod:`~gemseo.mlearning.transform.dimension_reduction.pca`
 """
-from __future__ import division, unicode_literals
+from __future__ import annotations
 
-from typing import NoReturn, Optional, Union
+from typing import NoReturn
 
 from numpy import ndarray
 
-from gemseo.mlearning.transform.transformer import Transformer, TransformerFitOptionType
+from gemseo.mlearning.transform.transformer import Transformer
+from gemseo.mlearning.transform.transformer import TransformerFitOptionType
 
 
 class DimensionReduction(Transformer):
@@ -41,25 +40,26 @@ class DimensionReduction(Transformer):
 
     def __init__(
         self,
-        name="DimensionReduction",  # type: str
-        n_components=5,  # type: int
-        **parameters  # type: Optional[Union[float,int,str,bool]]
-    ):  # type: (...) -> None
+        name: str = "DimensionReduction",
+        n_components: int | None = None,
+        **parameters: bool | int | float | ndarray | str | None,
+    ) -> None:
         """
         Args:
             name: A name for this transformer.
             n_components: The number of components of the latent space.
+                If ``None``,
+                use the maximum number allowed by the technique,
+                typically ``min(n_samples, n_features)``.
             **parameters: The parameters of the transformer.
         """
-        super(DimensionReduction, self).__init__(
-            name, n_components=n_components, **parameters
-        )
+        super().__init__(name, n_components=n_components, **parameters)
 
-    def fit(
+    def _fit(
         self,
-        data,  # type: ndarray
-        *args  # type: TransformerFitOptionType
-    ):  # type: (...) -> NoReturn
+        data: ndarray,
+        *args: TransformerFitOptionType,
+    ) -> NoReturn:
         """Fit the transformer to the data.
 
         Args:
@@ -68,6 +68,6 @@ class DimensionReduction(Transformer):
         raise NotImplementedError
 
     @property
-    def n_components(self):  # type: (...) -> int
+    def n_components(self) -> int:
         """The number of components."""
         return self.parameters["n_components"]
