@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2021 IRT Saint Exupéry, https://www.irt-saintexupery.com
 #
 # This program is free software; you can redistribute it and/or
@@ -13,13 +12,12 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
 # Contributors:
 #    INITIAL AUTHORS - API and implementation and/or documentation
 #        :author: Pierre-Jean Barjhoux
 #    OTHER AUTHORS   - MACROSCOPIC CHANGES
 """A constraints plot."""
-from __future__ import division, unicode_literals
+from __future__ import annotations
 
 import logging
 from typing import Sequence
@@ -28,7 +26,8 @@ import numpy as np
 from matplotlib import pyplot
 
 from gemseo.algos.opt_problem import OptimizationProblem
-from gemseo.post.core.colormaps import PARULA, RG_SEISMIC
+from gemseo.post.core.colormaps import PARULA
+from gemseo.post.core.colormaps import RG_SEISMIC
 from gemseo.post.opt_post_processor import OptPostProcessor
 from gemseo.utils.compatibility.matplotlib import SymLogNorm
 
@@ -48,104 +47,102 @@ class ConstraintsHistory(OptPostProcessor):
 
     def __init__(
         self,
-        opt_problem,  # type: OptimizationProblem
-    ):  # type: (...) -> None
-        super(ConstraintsHistory, self).__init__(opt_problem)
-        self.cmap = PARULA  # "viridis"  # "jet"
-        self.ineq_cstr_cmap = RG_SEISMIC  # "seismic" "PRGn_r"
-        self.eq_cstr_cmap = "seismic"  # "seismic" "PRGn_r"
+        opt_problem: OptimizationProblem,
+    ) -> None:
+        super().__init__(opt_problem)
+        self.cmap = PARULA
+        self.ineq_cstr_cmap = RG_SEISMIC
+        self.eq_cstr_cmap = "seismic"
 
     def _plot(
         self,
-        constraints_list,  # type: Sequence[str]
-    ):  # type: (...) -> None
+        constraint_names: Sequence[str],
+    ) -> None:
         """
         Args:
-            constraints_list: The names of the constraints.
+            constraint_names: The names of the constraints.
 
         Raises:
-            ValueError: If a given element of `constraints_list` is not a
-                function.
+            ValueError: If a given element of `constraint_names` is not a function.
         """
-        # retrieve the constraints values
-        add_dv = False
-        all_constr_names = self.opt_problem.get_constraints_names()
-
-        for func in list(constraints_list):
-            if func not in all_constr_names:
+        all_constraint_names = self.opt_problem.constraint_names.keys()
+        for constraint_name in constraint_names:
+            if constraint_name not in all_constraint_names:
                 raise ValueError(
                     "Cannot build constraints history plot, "
-                    "function {} is not among the constraints names "
-                    "or does not exist.".format(func)
+                    f"function {constraint_name} is not among the constraints names "
+                    "or does not exist."
                 )
 
-        vals, vname, _ = self.database.get_history_array(
-            constraints_list, add_dv=add_dv
+        constraint_names = self.opt_problem.get_function_names(constraint_names)
+        constraint_history, constraint_names, _ = self.database.get_history_array(
+            constraint_names, add_dv=False
         )
 
         # harmonization of tables format because constraints can be vectorial
         # or scalars. *vals.shape[0] = iteration, *vals.shape[1] = cstr values
-        vals = np.atleast_3d(vals)
-        vals = vals.reshape((vals.shape[0], vals.shape[1] * vals.shape[2]))
+        constraint_history = np.atleast_3d(constraint_history)
+        constraint_history = constraint_history.reshape(
+            (
+                constraint_history.shape[0],
+                constraint_history.shape[1] * constraint_history.shape[2],
+            )
+        )
 
         # prepare the main window
-        nb_iter = vals.shape[0]
+        n_iterations = len(constraint_history)
 
-        n_funcs = len(vname)
-        nrows = n_funcs // 2
-        if 2 * nrows < n_funcs:
-            nrows += 1
+        n_funcs = len(constraint_names)
+        n_rows = n_funcs // 2
+        if 2 * n_rows < n_funcs:
+            n_rows += 1
 
         fig, axes = pyplot.subplots(
-            nrows=nrows,
+            nrows=n_rows,
             ncols=2,
             sharex=True,
             sharey=False,
             figsize=self.DEFAULT_FIG_SIZE,
         )
 
-        fig.suptitle("Evolution of the constraints " + "w.r.t. iterations", fontsize=14)
+        fig.suptitle("Evolution of the constraints w.r.t. iterations", fontsize=14)
 
-        n_subplots = nrows * 2
+        n_subplots = n_rows * 2
 
-        x_iter = np.arange(nb_iter)
-        y_lim = 0.0
-        vmax = 0.0
+        iterations = np.arange(n_iterations)
         # for each subplot
-        for values, name, i in zip(vals.T, vname, np.arange(n_subplots)):
+        for history, name, i in zip(
+            constraint_history.T, constraint_names, np.arange(n_subplots)
+        ):
             # prepare the graph
             axe = axes.ravel()[i]
             axe.grid(True)
             axe.set_title(name)
-            axe.set_xlim([0, nb_iter])
-            axe.axhline(y_lim, color="k", linewidth=2)
+            axe.set_xlim([0, n_iterations])
+            axe.axhline(0.0, color="k", linewidth=2)
 
             # plot values in lines
-            axe.plot(x_iter, values)
+            axe.plot(iterations, history)
 
             # Plot color bars
-            cstr_matrix = np.atleast_2d(values)
-            cmap = self.ineq_cstr_cmap
-            vmax = max(vmax, np.max(np.abs(cstr_matrix)))
-            extent = -0.5, nb_iter - 0.5, np.min(cstr_matrix), np.max(cstr_matrix)
-
-            norm = SymLogNorm(linthresh=1.0, vmin=-vmax, vmax=vmax)
-
+            maximum = np.max(np.abs(history))
             axe.imshow(
-                cstr_matrix,
-                cmap=cmap,
+                np.atleast_2d(history),
+                cmap=self.ineq_cstr_cmap,
                 interpolation="nearest",
                 aspect="auto",
-                extent=extent,
-                norm=norm,
+                extent=[-0.5, n_iterations - 0.5, np.min(history), np.max(history)],
+                norm=SymLogNorm(linthresh=1.0, vmin=-maximum, vmax=maximum),
                 alpha=0.6,
             )
 
             # plot vertical line the last time that g(x)=0
-            indices = np.where(np.diff(np.sign(values)))[0]
+            indices = np.where(np.diff(np.sign(history)))[0]
             if indices.size != 0:
                 ind = indices[-1]
-                x_lim = np.interp(y_lim, values[ind : ind + 2], x_iter[ind : ind + 2])
+                x_lim = np.interp(
+                    0.0, history[ind : ind + 2], iterations[ind : ind + 2]
+                )
                 axe.axvline(x_lim, color="k", linewidth=2)
 
         self._add_figure(fig)
