@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2021 IRT Saint Exupéry, https://www.irt-saintexupery.com
 #
 # This program is free software; you can redistribute it and/or
@@ -13,7 +12,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
 # Contributors:
 #    INITIAL AUTHORS - initial API and implementation and/or initial
 #                           documentation
@@ -48,34 +46,47 @@ arguments
 In the latter case, the color scale is composed of only two values: one for
 the samples positively classified and one for the others.
 """
-from __future__ import division, unicode_literals
-
-from typing import List, Mapping
+from __future__ import annotations
 
+from matplotlib.axes import Axes
 from matplotlib.figure import Figure
 from numpy import inf
 from pandas.plotting import parallel_coordinates
 
+from gemseo.core.dataset import Dataset
 from gemseo.post.dataset.dataset_plot import DatasetPlot
 
 
 class ParallelCoordinates(DatasetPlot):
     """Parallel coordinates."""
 
-    def _plot(
+    def __init__(
         self,
-        properties,  # type: Mapping
-        classifier,  # type: str
-        lower=-inf,  # type: float
-        upper=inf,  # type: float
-        **kwargs
-    ):  # type: (...) -> List[Figure]
+        dataset: Dataset,
+        classifier: str,
+        lower: float = -inf,
+        upper: float = inf,
+        **kwargs,
+    ) -> None:
         """
         Args:
             classifier: The name of the variable to group the data.
             lower: The lower bound of the cluster.
             upper: The upper bound of the cluster.
         """
+        super().__init__(
+            dataset, classifier=classifier, lower=lower, upper=upper, kwargs=kwargs
+        )
+
+    def _plot(
+        self,
+        fig: None | Figure = None,
+        axes: None | Axes = None,
+    ) -> list[Figure]:
+        classifier = self._param.classifier
+        upper = self._param.upper
+        lower = self._param.lower
+        kwargs = self._param.kwargs
         if classifier not in self.dataset.variables:
             raise ValueError(
                 "Classifier must be one of these names: "
@@ -90,15 +101,19 @@ class ParallelCoordinates(DatasetPlot):
             return lower < row[varname] < upper
 
         if lower != -inf or upper != inf:
-            cluster = "{} < {} < {}".format(lower, label, upper)
-            cluster = ("classifiers", cluster, "0")
+            cluster = ("classifiers", f"{lower} < {label} < {upper}", "0")
             dataframe[cluster] = dataframe.apply(is_btw, axis=1)
-        axes = parallel_coordinates(dataframe, cluster, cols=columns, **kwargs)
+
+        fig, axes = self._get_figure_and_axes(fig, axes)
+        axes = parallel_coordinates(dataframe, cluster, cols=columns, ax=axes, **kwargs)
         axes.set_xticklabels(self._get_variables_names(columns))
         if lower != -inf or upper != inf:
-            default_title = "Cobweb plot based on the classifier: {}".format(cluster[1])
+            default_title = f"Cobweb plot based on the classifier: {cluster[1]}"
         else:
             default_title = None
             axes.get_legend().remove()
+
+        axes.set_xlabel(self.xlabel)
+        axes.set_ylabel(self.ylabel)
         axes.set_title(self.title or default_title)
-        return [axes.figure]
+        return [fig]
