@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2021 IRT Saint Exupéry, https://www.irt-saintexupery.com
 #
 # This program is free software; you can redistribute it and/or
@@ -13,7 +12,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
 # Contributors:
 #    INITIAL AUTHORS - initial API and implementation and/or initial
 #                           documentation
@@ -21,31 +19,30 @@
 #    OTHER AUTHORS   - MACROSCOPIC CHANGES
 r"""Draw a scatter plot from a :class:`.Dataset`.
 
-A :class:`Scatter` plot represents a set of points
+A :class:`.Scatter` plot represents a set of points
 :math:`\{x_i,y_i\}_{1\leq i \leq n}` as markers on a classical plot
 where the color of points can be heterogeneous.
 """
-from __future__ import division, unicode_literals
+from __future__ import annotations
 
-from typing import List, Mapping
-
-import matplotlib.pyplot as plt
+from matplotlib.axes import Axes
 from matplotlib.figure import Figure
 
+from gemseo.core.dataset import Dataset
 from gemseo.post.dataset.dataset_plot import DatasetPlot
 
 
 class Scatter(DatasetPlot):
     """Plot curve y versus x."""
 
-    def _plot(
+    def __init__(
         self,
-        properties,  # type: Mapping
-        x,  # type: str
-        y,  # type: str
-        x_comp=0,  # type: str
-        y_comp=0,  # type: str
-    ):  # type: (...) -> List[Figure]
+        dataset: Dataset,
+        x: str,
+        y: str,
+        x_comp: str = 0,
+        y_comp: str = 0,
+    ) -> None:
         """
         Args:
             x: The name of the variable on the x-axis.
@@ -53,19 +50,34 @@ class Scatter(DatasetPlot):
             x_comp: The component of x.
             y_comp: The component of y.
         """
-        color = properties.get(self.COLOR) or "blue"
-        x_data = self.dataset[x][x][:, x_comp]
-        y_data = self.dataset[y][y][:, y_comp]
+        super().__init__(dataset, x=x, y=y, x_comp=x_comp, y_comp=y_comp)
 
-        fig = plt.figure()
-        axes = fig.add_subplot(1, 1, 1)
+    def _plot(
+        self,
+        fig: None | Figure = None,
+        axes: None | Axes = None,
+    ) -> list[Figure]:
+        x = self._param.x
+        y = self._param.y
+        x_comp = self._param.x_comp
+        y_comp = self._param.y_comp
+        color = self.color or "blue"
+        x_data = self.dataset[x][:, x_comp]
+        y_data = self.dataset[y][:, y_comp]
+
+        fig, axes = self._get_figure_and_axes(fig, axes)
         axes.scatter(x_data, y_data, color=color)
+
         if self.dataset.sizes[x] == 1:
             axes.set_xlabel(self.xlabel or x)
         else:
-            axes.set_xlabel(self.xlabel or "{}({})".format(x, x_comp))
+            axes.set_xlabel(self.xlabel or f"{x}({x_comp})")
+
         if self.dataset.sizes[y] == 1:
             axes.set_ylabel(self.ylabel or y)
         else:
-            axes.set_ylabel(self.ylabel or "{}({})".format(y, y_comp))
+            axes.set_ylabel(self.ylabel or f"{y}({y_comp})")
+
+        axes.set_title(self.title)
+
         return [fig]
