@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2021 IRT Saint Exupéry, https://www.irt-saintexupery.com
 #
 # This program is free software; you can redistribute it and/or
@@ -13,19 +12,19 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
 # Contributors:
 #    INITIAL AUTHORS - API and implementation and/or documentation
 #        :author: Francois Gallard
 #        :author: Damien Guenot
 #    OTHER AUTHORS   - MACROSCOPIC CHANGES
 """A Pareto Front."""
-from __future__ import division, unicode_literals
+from __future__ import annotations
 
 import logging
-from typing import List, Optional, Sequence, Tuple
+from typing import Sequence
 
-from numpy import full, ndarray
+from numpy import full
+from numpy import ndarray
 
 from gemseo.algos.pareto_front import generate_pareto_plots
 from gemseo.post.opt_post_processor import OptPostProcessor
@@ -34,38 +33,39 @@ LOGGER = logging.getLogger(__name__)
 
 
 class ParetoFront(OptPostProcessor):
-    """Compute the Pareto front Search for all non dominated points.
+    """Compute the Pareto front for a multi-objective problem.
 
-    For each point, check if it exists ``j`` such that there is no lower value
-    for ``obj_values[:,j]`` that does not degrade
-    at least one other objective ``obj_values[:,i]``.
+    The Pareto front of an optimization problem is the set of ``non-dominated`` points of
+    the design space for which there is no other point that improves an objective
+    without damaging another.
 
-    Generate a plot or a matrix of plots if there are more than 2 objectives.
-    Plot in red the locally non dominated points for the currrent two objectives.
-    Plot in green the globally (all objectives) Pareto optimal points.
+    This post-processing computes the Pareto front and generates a matrix of plots,
+    one per couple of objectives.
+    For a given plot, the red markers are the non-dominated points according to the
+    objectives of this plot and the green markers are the non-dominated points
+    according to all the objectives.
+    The latter are also called ``Pareto optimal points``.
     """
 
+    DEFAULT_FIG_SIZE = (10.0, 10.0)
+
     def _plot(
         self,
-        objectives=None,  # type: Optional[Sequence[str]]
-        objectives_labels=None,  # type: Optional[Sequence[str]]
-        figsize_x=10.0,  # type: float
-        figsize_y=10.0,  # type: float
-        show_non_feasible=True,  # type: bool
-    ):  # type: (...) -> None
+        objectives: Sequence[str] | None = None,
+        objectives_labels: Sequence[str] | None = None,
+        show_non_feasible: bool = True,
+    ) -> None:
         """
         Args:
             objectives: The functions names or design variables to plot.
                 If None, use the objective function (may be a vector).
             objectives_labels: The labels of the objective components.
                 If None, use the objective name suffixed by an index.
-            figsize_x: The size of figure in the horizontal direction (inches).
-            figsize_y: The size of figure in the vertical direction (inches).
             show_non_feasible: If True, show the non feasible points in the plot.
 
         Raises:
             ValueError: If the numbers of objectives and objectives
-             labels are different.
+                labels are different.
         """
         if objectives is None:
             objectives = [self.opt_problem.objective.name]
@@ -73,23 +73,24 @@ class ParetoFront(OptPostProcessor):
         all_funcs = self.opt_problem.get_all_functions_names()
         all_dv_names = self.opt_problem.design_space.variables_names
 
-        vals, vname = self.__compute_names_and_values(
+        sample_values, all_labels = self.__compute_names_and_values(
             all_dv_names, all_funcs, objectives
         )
 
-        non_feasible_samples = self.__compute_non_feasible_samples(vals)
+        non_feasible_samples = self.__compute_non_feasible_samples(sample_values)
 
         if objectives_labels is not None:
-            if len(vname) != len(objectives_labels):
+            if len(all_labels) != len(objectives_labels):
                 raise ValueError(
-                    "objective_labels shall have the same dimension as vname."
+                    "objective_labels shall have the same dimension as the number"
+                    " of objectives to plot."
                 )
-            vname = objectives_labels
+            all_labels = objectives_labels
 
         fig = generate_pareto_plots(
-            vals,
-            vname,
-            figsize=(figsize_x, figsize_y),
+            sample_values,
+            all_labels,
+            fig_size=self.DEFAULT_FIG_SIZE,
             non_feasible_samples=non_feasible_samples,
             show_non_feasible=show_non_feasible,
         )
@@ -98,56 +99,66 @@ class ParetoFront(OptPostProcessor):
 
     def __compute_names_and_values(
         self,
-        all_dv_names,  # type: Sequence[str]
-        all_funcs,  # type: Sequence[str]
-        objectives,  # type: Sequence[str]
-    ):  # type: (...) -> Tuple[ndarray,List[str]]
+        all_dv_names: Sequence[str],
+        all_funcs: Sequence[str],
+        objectives: Sequence[str],
+    ) -> tuple[ndarray, list[str]]:
         """Compute the names and values of the objective and design variables.
 
         Args:
-             add_dv_names: The design variables names.
+             all_dv_names: The design variables names.
              all_funcs: The function names.
              objectives: The objective names.
 
         Returns:
             The sample values and the sample names.
         """
-        # TODO: Those lines are not covered by the tests. It has to be
-        # investigated to see if it's dead code.
-        if not objectives:
-            # The function list only contains design variables
-            vals = self.database.get_x_history()
-            vname = self.database.set_dv_names(vals[0].shape[0])
-        else:
-            design_variables = []
-            for func in list(objectives):
-                self.__check_objective_name(all_dv_names, all_funcs, func, objectives)
-                self.__move_objective_to_design_variable(
-                    design_variables, func, objectives
-                )
+        design_variables = []
+        for func in list(objectives):
+            self.__check_objective_name(all_dv_names, all_funcs, func, objectives)
+            self.__move_objective_to_design_variable(design_variables, func, objectives)
 
-            if not design_variables:
-                design_variables = None
-                add_dv = False
-            else:
-                add_dv = True
-
-            vals, vname, _ = self.database.get_history_array(
-                objectives, design_variables, add_dv=add_dv
+        if not design_variables:
+            design_variables_labels = []
+            all_data_names = objectives
+            _, objective_labels, _ = self.database.get_history_array(
+                functions=objectives,
+                design_variables_names=None,
+                add_dv=False,
             )
-        return vals, vname
+        elif not objectives:
+            design_variables_labels = self._generate_x_names(variables=design_variables)
+            all_data_names = design_variables
+            objective_labels = []
+        else:
+            design_variables_labels = self._generate_x_names(variables=design_variables)
+            all_data_names = objectives + design_variables
+            _, objective_labels, _ = self.database.get_history_array(
+                functions=objectives,
+                design_variables_names=None,
+                add_dv=False,
+            )
+
+        all_data_names.sort()
+        all_labels = sorted(objective_labels + design_variables_labels)
+
+        sample_values = self.opt_problem.get_data_by_names(
+            names=all_data_names, as_dict=False, filter_non_feasible=False
+        )
+
+        return sample_values, all_labels
 
     def __check_objective_name(
         self,
-        all_dv_names,  # type: Sequence[str]
-        all_funcs,  # type: Sequence[str]
-        func,  # type: str
-        objectives,  # type: Sequence[str]
-    ):  # type: (...) -> None
+        all_dv_names: Sequence[str],
+        all_funcs: Sequence[str],
+        func: str,
+        objectives: Sequence[str],
+    ) -> None:
         """Check that the objective name is valid.
 
         Args:
-             add_dv_names: The design variables names.
+             all_dv_names: The design variables names.
              all_funcs: The function names.
              func: The function name.
              objectives: The objectives names.
@@ -171,10 +182,10 @@ class ParetoFront(OptPostProcessor):
 
     def __move_objective_to_design_variable(
         self,
-        design_variables,  # type: Sequence[str]
-        func,  # type: str
-        objectives,  # type: Sequence[str]
-    ):  # type: (...) -> None
+        design_variables: Sequence[str],
+        func: str,
+        objectives: Sequence[str],
+    ) -> None:
         """Move an objective to a design variable.
 
         If the given function is a design variable,
@@ -189,21 +200,19 @@ class ParetoFront(OptPostProcessor):
             objectives.remove(func)
             design_variables.append(func)
 
-    def __compute_non_feasible_samples(
-        self, vals  # type: ndarray
-    ):  # type: (...) -> ndarray
+    def __compute_non_feasible_samples(self, sample_values: ndarray) -> ndarray:
         """Compute the non-feasible indexes.
 
         Args:
-            vals: The sample values.
+            sample_values: The sample values.
 
         Returns:
-              An array of size ``n_samples``, True if the point is non feasible
+            An array of size ``n_samples``, True if the point is non feasible.
         """
         x_feasible, _ = self.opt_problem.get_feasible_points()
         feasible_indexes = [self.database.get_index_of(x) for x in x_feasible]
 
-        is_non_feasible = full(vals.shape[0], True)
+        is_non_feasible = full(sample_values.shape[0], True)
         is_non_feasible[feasible_indexes] = False
 
         return is_non_feasible
