@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2021 IRT Saint Exupéry, https://www.irt-saintexupery.com
 #
 # This program is free software; you can redistribute it and/or
@@ -13,7 +12,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
 # Contributors:
 #    INITIAL AUTHORS - initial API and implementation and/or initial
 #                         documentation
@@ -23,14 +21,15 @@
 Scalable study
 ==============
 """
-from __future__ import division, unicode_literals
+from __future__ import annotations
 
 import logging
 import os
 import pickle
 
 from matplotlib import pyplot as plt
-from numpy import arange, where
+from numpy import arange
+from numpy import where
 from numpy.random import rand
 
 from gemseo.core.coupling_structure import MDOCouplingStructure
@@ -75,7 +74,7 @@ COEFF_DIR = "coefficients"
 OPTIM_DIR = "opthistoryview"
 
 
-class TMParamSS(object):
+class TMParamSS:
 
     """This scalable parametric study realizes scalable studies with different scaling
     strategies.
@@ -138,10 +137,7 @@ class TMParamSS(object):
         assert isinstance(n_coupling, (int, list))
 
         n_lists = sum(
-            [
-                1 if isinstance(val, list) else 0
-                for val in (n_shared, n_local, n_coupling)
-            ]
+            1 if isinstance(val, list) else 0 for val in (n_shared, n_local, n_coupling)
         )
         if n_lists > 1:
             msg = "At most 1 value among (n_shared,n_local,n_coupling) can be a list !"
@@ -309,7 +305,7 @@ class TMParamSS(object):
             )
 
 
-class TMParamSSPost(object):
+class TMParamSSPost:
 
     """This class is dedicated to the post-treatment of TMParamSS results."""
 
@@ -370,7 +366,7 @@ class TMParamSSPost(object):
             plt.show()
 
 
-class TMScalableStudy(object):
+class TMScalableStudy:
 
     """This scalable study creates a scalable MDO problem from Tedford and Martins, 2010
     and compares its resolution according to different MDO formulations."""
@@ -424,10 +420,10 @@ class TMScalableStudy(object):
         self.n_calls = {}
         self.n_calls_linearize = {}
         self.exec_time = {}
-        self.formulation_options = {"MDF": {"sub_mda_class": "MDAGaussSeidel"}}
+        self.formulation_options = {"MDF": {"inner_mda_name": "MDAGaussSeidel"}}
         self.formulation_options["MDF"].update(MDA_TOLERANCE)
         self.disc_names = ["scenario", "mda", "mdo_chain", "sub_mda"]
-        tmp = sorted([disc.name for disc in self.problem.disciplines])
+        tmp = sorted(disc.name for disc in self.problem.disciplines)
         self.disc_names += tmp
         self.active_probability = active_probability
         self.feasibility_level = feasibility_level
@@ -459,9 +455,9 @@ class TMScalableStudy(object):
             mdo_chain_exec_time = mda.mdo_chain.exec_time
             mdo_chain_nc = mda.mdo_chain.n_calls
             mdo_chain_ncl = mda.mdo_chain.n_calls_linearize
-            sub_mda_exec_time = mda.sub_mda_list[0].exec_time
-            sub_mda_nc = mda.sub_mda_list[0].n_calls
-            sub_mda_ncl = mda.sub_mda_list[0].n_calls_linearize
+            sub_mda_exec_time = mda.inner_mdas[0].exec_time
+            sub_mda_nc = mda.inner_mdas[0].n_calls
+            sub_mda_ncl = mda.inner_mdas[0].n_calls_linearize
         else:
             mda_exec_time = 0.0
             mda_nc = 0
@@ -491,17 +487,19 @@ class TMScalableStudy(object):
         post_coeff=True,
         algo="NLOPT_SLSQP",
         algo_options=None,
+        xdsm_pdf=False,
     ):
-        """This method solves the scalable problem with a particular MDO formulation.
+        """Solve the scalable problem with a particular MDO formulation.
 
-        :param str formulation: MDO formulation name
-        :param int max_iter: maximum number of iterations
-        :param bool post_coupling: store coupling plots
-        :param bool post_optim: store optimization plots
-        :param bool post_coeff: store coefficients plots
-        :param algo: algorithm name to solve the problem
-        :param algo_options: inequality and equality tolerance,
-            xtol etc..
+        Args:
+            formulation: The name of the MDO formulation.
+            max_iter: THe maximum number of iterations.
+            post_coupling: Whether to store the coupling plots.
+            post_optim: Whether to store the optimization plots.
+            post_coeff: Whether to store the coefficients plots.
+            algo: The name of the algorithm used to solve the problem.
+            algo_options: The options for the algorithm.
+            xdsm_pdf: Whether to export the xdsm in pdf.
         """
         if algo_options is None:
             algo_options = ALGO_OPTIONS
@@ -517,7 +515,7 @@ class TMScalableStudy(object):
             formulation,
             OBJECTIVE_NAME,
             self.problem.design_space,
-            **self.formulation_options.get(formulation, {})
+            **self.formulation_options.get(formulation, {}),
         )
         LOGGER.info("Make the starting point feasible.")
         for disc in range(self.n_disciplines):
@@ -545,7 +543,9 @@ class TMScalableStudy(object):
         if post_coupling:
             path = mkdir(self.directory, COUPLING_DIR)
             scenario.xdsmize(
-                latex_output=True, outdir=path, outfilename=formulation + "_xdsm"
+                latex_output=xdsm_pdf,
+                outdir=path,
+                outfilename=formulation + "_xdsm",
             )
             coupling_structure = MDOCouplingStructure(scenario.disciplines)
             coupling_structure.plot_n2_chart(file_path=os.path.join(path, "n2.pdf"))
@@ -586,15 +586,15 @@ class TMScalableStudy(object):
         """
         msg = [
             "Scalable study",
-            ".... {} disciplines".format(self.n_disciplines),
-            ".... {} shared design parameters".format(self.n_shared),
-            ".... {} local design parameters per discipline".format(self.n_local),
-            ".... {} coupling variables per discipline".format(self.n_coupling),
+            f".... {self.n_disciplines} disciplines",
+            f".... {self.n_shared} shared design parameters",
+            f".... {self.n_local} local design parameters per discipline",
+            f".... {self.n_coupling} coupling variables per discipline",
         ]
         if self.formulations:
             msg.append("MDO formulations")
         for formulation in self.formulations:
-            msg.append(".... {}".format(formulation))
+            msg.append(f".... {formulation}")
             for discipline in self.problem.disciplines:
                 msg.append(self.__elementary_str(formulation, discipline.name))
             if "mda" in self.exec_time[formulation]:
