@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2021 IRT Saint Exupéry, https://www.irt-saintexupery.com
 #
 # This program is free software; you can redistribute it and/or
@@ -13,7 +12,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
 # Contributors:
 #    INITIAL AUTHORS - API and implementation and/or documentation
 #        :author: Francois Gallard, Charlie Vanaret
@@ -22,19 +20,20 @@
 Linear solvers wrapper
 **********************
 """
-from __future__ import division, unicode_literals
+from __future__ import annotations
 
 import logging
 
 import numpy as np
 import scipy.sparse.linalg as scipy_linalg
 from scipy.sparse.base import issparse
-from scipy.sparse.linalg import bicgstab, cgs
+from scipy.sparse.linalg import bicgstab
+from scipy.sparse.linalg import cgs
 
 LOGGER = logging.getLogger(__name__)
 
 
-class LinearSolver(object):
+class LinearSolver:
     """Solve a linear system Ax=b."""
 
     LGMRES = "lgmres"
@@ -48,7 +47,8 @@ class LinearSolver(object):
     def _check_linear_solver(linear_solver):
         """Check that linear solver is available.
 
-        :param linear_solver: name of linear solver used to solve linear solver
+        Args:
+            linear_solver: The name of the linear solver to solve the linear problem.
         """
         solver = LinearSolver.AVAILABLE_SOLVERS.get(linear_solver, None)
         if solver is None:
@@ -59,12 +59,16 @@ class LinearSolver(object):
 
     @staticmethod
     def _check_b(a_mat, b_vec):
-        """Check the dimensions of the vector b converts it to ndarray if sparse, for
-        lgmres needs.
+        """Check the dimensions of the vector b and convert it to ndarray if sparse.
 
-        :param a_mat: the matrix A
-        :param b_vec: the vector b
-        :returns: the vector b with consistent dimensions
+        For lgmres needs.
+
+        Args:
+            a_mat: The matrix A.
+            b_vec: The vector b.
+
+        Returns:
+            The vector b with consistent dimensions.
         """
         if len(b_vec.shape) == 2 and b_vec.shape[1] != 1:
             LOGGER.error(
@@ -80,30 +84,33 @@ class LinearSolver(object):
             b_vec = b_vec.toarray()
         return b_vec.real
 
-    def solve(self, a_mat, b_vec, linear_solver="lgmres", **kwargs_lin):
-        """Solves the linear system Ax=b using scipy sparse GMRES solver.
+    def solve(self, a_mat, b_vec, linear_solver="lgmres", **options):
+        """Solve the linear system :math:`Ax=b`.
 
-        :param a_mat: matrix A of the system, can be a sparse matrix
-        :param b_vec: second member
-        :param linear_solver: name of linear solver (Default value = 'lgmres')
-        :param kwargs_lin: arguments passed to the scipy linear solver
-        :returns: solution x such that A.x=b
+        Args:
+            a_mat: The matrix :math:`A` of the system, can be a sparse matrix.
+            b_vec: The second member :math:`b` of the system.
+            linear_solver: The name of linear solver.
+            **options: The options of the linear solver.
+
+        Returns:
+            The solution :math:`x` such that :math:`Ax=b`.
         """
         scipy_linear_solver = LinearSolver._check_linear_solver(linear_solver)
 
         # check the dimensions of b
         b_vec = LinearSolver._check_b(a_mat, b_vec)
         # solve the system
-        if "tol" not in kwargs_lin:
-            kwargs_lin["tol"] = 1e-8
-        kwargs_lin["atol"] = kwargs_lin["tol"]
+        if "tol" not in options:
+            options["tol"] = 1e-8
+        options["atol"] = options["tol"]
 
-        if "maxiter" not in kwargs_lin:
-            kwargs_lin["maxiter"] = 50 * len(b_vec)
+        if "maxiter" not in options:
+            options["maxiter"] = 50 * len(b_vec)
         else:
-            kwargs_lin["maxiter"] = min(kwargs_lin["maxiter"], 50 * len(b_vec))
+            options["maxiter"] = min(options["maxiter"], 50 * len(b_vec))
         sol, info = scipy_linear_solver(
-            A=a_mat, b=b_vec, outer_v=self.outer_v, **kwargs_lin
+            A=a_mat, b=b_vec, outer_v=self.outer_v, **options
         )
         base_msg = "scipy linear solver algorithm stop info: "
         if info > 0:
@@ -114,29 +121,29 @@ class LinearSolver(object):
             LOGGER.warning(total_msg)
 
             sol, info = bicgstab(
-                a_mat, b_vec, sol, maxiter=50 * len(b_vec), atol=kwargs_lin["atol"]
+                a_mat, b_vec, sol, maxiter=50 * len(b_vec), atol=options["atol"]
             )
             diff = a_mat.dot(sol) - b_vec.T
             res = np.sqrt(np.sum(diff))
 
-            total_msg = "{} --- --- residual = {}".format(base_msg, res)
+            total_msg = f"{base_msg} --- --- residual = {res}"
             LOGGER.warning(total_msg)
-            total_msg = "{} --- --- info = {}".format(base_msg, info)
+            total_msg = f"{base_msg} --- --- info = {info}"
             LOGGER.warning(total_msg)
 
             if info < 0:
-                total_msg = "{} --- trying cgs method".format(base_msg)
+                total_msg = f"{base_msg} --- trying cgs method"
                 LOGGER.warning(total_msg)
 
                 sol, info = cgs(
-                    a_mat, b_vec, sol, maxiter=50 * len(b_vec), atol=kwargs_lin["atol"]
+                    a_mat, b_vec, sol, maxiter=50 * len(b_vec), atol=options["atol"]
                 )
                 diff = a_mat.dot(sol) - b_vec.T
                 res = np.sqrt(np.sum(diff))
 
-                total_msg = "{} --- --- residual = {}".format(base_msg, res)
+                total_msg = f"{base_msg} --- --- residual = {res}"
                 LOGGER.warning(total_msg)
-                total_msg = "{} --- --- info = {}".format(base_msg, info)
+                total_msg = f"{base_msg} --- --- info = {info}"
                 LOGGER.warning(total_msg)
         elif info < 0:
             msg = "illegal input or breakdown"
