@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2021 IRT Saint Exupéry, https://www.irt-saintexupery.com
 #
 # This program is free software; you can redistribute it and/or
@@ -13,7 +12,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
 # Contributors:
 #    INITIAL AUTHORS - initial API and implementation and/or
 #                      initial documentation
@@ -27,7 +25,7 @@ class DummyDisciplineIMP(MDODiscipline):
     """Dummy."""
 
     def __init__(self, opts1=0, jac_approx_n_processes=1):
-        super(DummyDisciplineIMP, self).__init__()
+        super().__init__()
         self.opts1 = opts1
         self.jac_approx_n_processes = jac_approx_n_processes
 
