@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2021 IRT Saint Exupéry, https://www.irt-saintexupery.com
 #
 # This program is free software; you can redistribute it and/or
@@ -13,7 +12,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
 # Contributors:
 #    INITIAL AUTHORS - initial API and implementation and/or
 #                      initial documentation
@@ -30,7 +28,7 @@ def execute(infile=None, outfile=None):
     infile = infile or parser.parse_args().i
     outfile = outfile or parser.parse_args().o
 
-    with open(infile, "r") as input_f:
+    with open(infile) as input_f:
         data = json.load(input_f)
 
     with open(outfile, "w") as fout:
